# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We don't really need ExtUtils::MakeMaker ≥ 6.64
%global old_eumm %(perl -MExtUtils::MakeMaker -e 'print (($ExtUtils::MakeMaker::VERSION < 6.64) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Test-Requires
Summary:	Checks to see if a given module can be loaded
Version:	0.11
Release:	11.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Requires
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Requires-%{version}.tar.gz
Patch0:		Test-Requires-0.11-old-EU:MM.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(base)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder::Module)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Test::More) >= 0.47
# Extra Tests
%if 0%{!?perl_bootstrap:1}
# Test::Perl::Critic → Perl::Critic → PPIx::Regexp → Test::Kwalitee →
#   Module::CPANTS::Analyse → Test::Warn → Sub::Uplevel → Pod::Wordlist::hanekomu → Test::Requires
BuildRequires:	perl(Test::Perl::Critic)
%endif
# Runtime
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
Test::Requires checks to see if the module can be loaded.

If this fails, rather than failing tests this skips all tests.

%prep
%setup -q -n Test-Requires-%{version}

# We don't really need ExtUtils::MakeMaker ≥ 6.64
%if %{old_eumm}
%patch0
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
# note the "skipped" warnings indicate success :)
make test
make test TEST_FILES="xt/*.t"

%files
%license LICENSE
%doc Changes README.md t/ xt/
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Requires.3*

%changelog
* Mon Mar  6 2023 Paul Howarth <paul@city-fan.org> - 0.11-11
- Use SPDX-format license tag
- Drop decade-old obsoletes/provides for old tests sub-package
- Drop support for building with rpm < 4.9
- Use %%license unconditionally

* Thu May 14 2020 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11
  - Re-packaging

* Wed Jun  5 2019 Paul Howarth <paul@city-fan.org> - 0.10-17
- Perl 5.30 rebuild

* Thu Apr  5 2018 Paul Howarth <paul@city-fan.org> - 0.10-10
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Jul 26 2016 Paul Howarth <paul@city-fan.org> - 0.10-5
- Fix FTBFS when perl is not in the minimal buildroot
- Simplify find command using -delete
- BR: perl-generators where available

* Tue Jul 21 2015 Paul Howarth <paul@city-fan.org> - 0.10-1
- Update to 0.10
  - Support 5.6 again
- Add patch to support building with ExtUtils::MakeMaker < 6.64

* Tue Jul 21 2015 Paul Howarth <paul@city-fan.org> - 0.09-1
- Update to 0.09
  - Requires 5.8.1
- Use %%license where possible

* Wed Jul 16 2014 Paul Howarth <paul@city-fan.org> - 0.08-1
- Update to 0.08
  - Switch to ExtUtils::MakeMaker
- Drop %%defattr, redundant since rpm 4.4

* Tue Feb 18 2014 Paul Howarth <paul@city-fan.org> - 0.07-5
- Specify all dependencies (#1066077)

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 0.07-2
- Perl 5.18 rebuild

* Mon Jul  1 2013 Paul Howarth <paul@city-fan.org> - 0.07-1
- Update to 0.07
  - If the RELEASE_TESTING environment variable is true, then instead of
    skipping tests, Test::Requires bails out
  - Document that use Test::Requires "5.010" works
- Switch to Module::Build flow
- Classify buildreqs by usage
- Package upstream's new LICENSE and README.md files

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.06-8
- Perl 5.16 post-bootstrap rebuild

* Mon Jun 25 2012 Paul Howarth <paul@city-fan.org> - 0.06-7
- BR: perl(base), perl(Cwd) and perl(Data::Dumper)

* Thu Mar 22 2012 Paul Howarth <paul@city-fan.org> - 0.06-6
- Provide/Obsolete old tests subpackage from Fedora
- BR: at least version 0.61 of Test::More as per upstream

* Fri Mar 16 2012 Paul Howarth <paul@city-fan.org> - 0.06-5
- Don't BR: perl(Test::Perl::Critic) when bootstrapping
- Don't need to remove empty directories from buildroot
- Don't need explicit dependency on perl(Test::Builder::Module) if we have
  rpm ≥ 4.9 as it can auto-detect it

* Mon Aug  8 2011 Paul Howarth <paul@city-fan.org> - 0.06-4
- Workaround for old hunspell versions no longer needed as the issue is
  patched in perl-Test-Spelling-0.14-3

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 0.06-3
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> - 0.06-2
- Nobody else likes macros for commands

* Mon Sep 27 2010 Paul Howarth <paul@city-fan.org> - 0.06-1
- Update to 0.06 (support Perl 5.6.0 or later, because Mouse needs it)
- BR: perl(Test::Spelling)
- Add patch to fix spelling test on F-9 and F-10

* Sat Aug 28 2010 Paul Howarth <paul@city-fan.org> - 0.05-1
- Initial RPM version
